@@ -3,7 +3,7 @@
     Copyright (C) 2010-2015 — IanniX Association
 
     Project Manager: Thierry Coduys (http://www.le-hub.org)
-    Development:     Guillaume Jacquemin (http://www.buzzinglight.com)
+    Development:     Guillaume Jacquemin (https://www.buzzinglight.com)
 
     This file was written by Guillaume Jacquemin.
 
@@ -93,8 +93,8 @@ UiView::UiView(QWidget *parent) :
     Application::colorTheme            .setAction(ui->actionLight,                    "guiColorTheme");
     Application::paintAxisGrid         .setAction(ui->actionGrid,                     "guiPaintAxisGrid");
     Application::paintLabel            .setAction(ui->actionToggleLabel,              "guiPaintLabel");
-    Application::mouseSnapX            .setAction(ui->actionSnapXGrid,                "guiMouseSnapX");
-    Application::mouseSnapY            .setAction(ui->actionSnapYGrid,                "guiMouseSnapY");
+    Application::mouseSnapX            .setAction(ui->actionSnapXGrid);
+    Application::mouseSnapY            .setAction(ui->actionSnapYGrid);
     Application::allowLockPos          .setAction(ui->actionLockPos,                  "guiAllowLockPos");
     Application::allowSelectionCursors .setAction(ui->actionAllow_cursors_selection,  "guiAllowSelectionCursors");
     Application::allowSelectionCurves  .setAction(ui->actionAllow_curves_selection,   "guiAllowSelectionCurves");
@@ -141,6 +141,7 @@ UiView::UiView(QWidget *parent) :
     connect(ui->actionAlign_ellipse,        SIGNAL(triggered()), SLOT(actionAlign_ellipse()));
 
     delete ui->renderPreview;
+    ui->renderPreview = 0;
     ui->renderPreview = new UiRenderPreview(ui->pagePerf, ui->render);
     ui->pagePerf->layout()->addWidget(ui->renderPreview);
     fullscreenDisplays = QApplication::desktop();
