@@ -3,7 +3,7 @@
     Copyright (C) 2010-2015 — IanniX Association
 
     Project Manager: Thierry Coduys (http://www.le-hub.org)
-    Development:     Guillaume Jacquemin (http://www.buzzinglight.com)
+    Development:     Guillaume Jacquemin (https://www.buzzinglight.com)
 
     This file was written by Guillaume Jacquemin.
 
