@@ -3,7 +3,7 @@
     Copyright (C) 2010-2015 — IanniX Association
 
     Project Manager: Thierry Coduys (http://www.le-hub.org)
-    Development:     Guillaume Jacquemin (http://www.buzzinglight.com)
+    Development:     Guillaume Jacquemin (https://www.buzzinglight.com)
 
     This file was written by Guillaume Jacquemin.
 
@@ -44,7 +44,7 @@ int main(int argc, char *argv[]) {
     //iannixApp.installTranslator(&translator);
 
     QString appName    = "IanniX ";
-    QString appVersion = "0.9.17";
+    QString appVersion = "0.9.20";
 
 #ifdef Q_OS_MAC
     appName += "Mac";
@@ -61,8 +61,8 @@ int main(int argc, char *argv[]) {
 
     QCoreApplication::setApplicationName   (appName.trimmed());
     QCoreApplication::setApplicationVersion(appVersion.trimmed());
-    QCoreApplication::setOrganizationName  ("buzzing light");
-    QCoreApplication::setOrganizationDomain("org.iannix.desktop");
+    QCoreApplication::setOrganizationName  ("IanniX");
+    QCoreApplication::setOrganizationDomain("iannix");
 
     iannixApp.launch(argc, argv);
 
@@ -103,14 +103,13 @@ void IanniXApp::launch(int &argc, char **argv) {
     if(Application::pathApplication.absoluteFilePath().endsWith("/IanniX-build"))
         Application::pathApplication = QFileInfo(Application::pathApplication.absoluteFilePath().remove("-build"));
 
-    qDebug("Pathes");
+    qDebug("Paths");
     qDebug("\tDocuments  : %s", qPrintable(Application::pathDocuments  .absoluteFilePath()));
     qDebug("\tApplication: %s", qPrintable(Application::pathApplication.absoluteFilePath()));
     qDebug("\tCurrent    : %s", qPrintable(Application::pathCurrent    .absoluteFilePath()));
     qDebug("Arguments");
-    for(quint16 i = 0 ; i < argc ; i++) {
+    for(quint16 i = 0 ; i < argc ; i++)
         qDebug("\t%2d=\t%s", i, argv[i]);
-    }
     /*
     if(Application::pathCurrent.absoluteFilePath().startsWith("/Users/Guillaume/Documents/buzzinglight/Projets/Coduys/IanniX/IanniX"))
         generateHelp();
@@ -350,6 +349,7 @@ void IanniXApp::setHelp() {
     Help::categories["commands"].infos << HelpInfo(COMMAND_ACTIVE					, tr(""), tr(""), tr("<target> <0|1>"));
     Help::categories["commands"].infos << HelpInfo(COMMAND_CURSOR_CURVE				, tr("Objects identification"), tr("Associates a cursor to a curve"), tr("<target> <curve_id>"));
     Help::categories["commands"].infos << HelpInfo(COMMAND_CURSOR_START				, tr(""), tr(""), tr("<target> <easing> <0> <loop_pattern>"));
+    Help::categories["commands"].infos << HelpInfo(COMMAND_CURSOR_FIRE				, tr(""), tr(""), tr("<target> <mode: none, group, all>"));
     Help::categories["commands"].infos << HelpInfo(COMMAND_CURSOR_WIDTH				, tr(""), tr(""), tr("<target> <width>"));
     Help::categories["commands"].infos << HelpInfo(COMMAND_CURSOR_DEPTH				, tr(""), tr(""), tr("<target> <depth>"));
     Help::categories["commands"].infos << HelpInfo(COMMAND_CURSOR_SPEED				, tr(""), tr(""), tr("<target> <speed>\n<target> auto <duration>\n<target> lock <fixed_speed\n<target> autolock <fixed_duration>"));
