@@ -3,7 +3,7 @@
     Copyright (C) 2010-2015 — IanniX Association
 
     Project Manager: Thierry Coduys (http://www.le-hub.org)
-    Development:     Guillaume Jacquemin (http://www.buzzinglight.com)
+    Development:     Guillaume Jacquemin (https://www.buzzinglight.com)
 
     This file was written by Guillaume Jacquemin.
 
@@ -31,14 +31,11 @@
 #include <QColor>
 #include <QHash>
 #include <QHashIterator>
-#include <QGLWidget>
-#include <QPainter>
 #include <QTimer>
 #include <QTreeWidgetItem>
 #include <QtCore/qmath.h>
 #include "iannix_spec.h"
 #include "iannix_cmd.h"
-
 #include "misc/application.h"
 #include "transport/transport.h"
 
